#
# spec file for package ghc-async
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name async
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.2.5
Release:        4.3
Summary:        Run IO operations asynchronously and wait for their results
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/3.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
%endif

%description
This package provides a higher-level interface over threads, in which an 'Async
a' is a concurrent thread that will eventually deliver a value of type 'a'.
The package provides ways to create 'Async' computations, wait for their
results, and cancel them.

Using 'Async' is safer than using threads in two ways:

* When waiting for a thread to return a result, if the thread dies with an
exception then the caller must either re-throw the exception ('wait') or handle
it ('waitCatch'); the exception cannot be ignored.

* The API makes it possible to build a tree of threads that are automatically
killed when their parent dies (see 'withAsync').

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Nov  6 2024 Peter Simons <psimons@suse.com>
- Update async to version 2.2.5 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Aug 15 2024 Peter Simons <psimons@suse.com>
- Update async to version 2.2.5 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Apr 13 2024 Peter Simons <psimons@suse.com>
- Update async to version 2.2.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov 21 2023 Peter Simons <psimons@suse.com>
- Update async to version 2.2.5.
  [#]# Changes in 2.2.5
  - #117: Document that empty for Concurrently waits forever
  - #120: Add ConcurrentlyE.
  - #123: Fix failing concurrentlyE tests in older GHCs.
  - #124: Allow hashable 1.4
  - #126: Semigroup and Monoid instances for ConcurrentlyE
  - #120: Add ConcurrentlyE
  - #138: expose internals as Control.Concurrent.Async.Internal
  - #131: Fix typos in docs
  - #132: waitAny(Catch): clarify non-empty input list requirement
  - #142: Add cancelMany
  - #135, #145, #150: Support for GHC 9.4, 9.6, 9.8
  - Document that empty for Concurrently waits forever.
* Tue Oct 10 2023 Peter Simons <psimons@suse.com>
- Update async to version 2.2.4 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Mar 12 2023 Peter Simons <psimons@suse.com>
- Update async to version 2.2.4 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Aug 12 2022 Peter Simons <psimons@suse.com>
- Update async to version 2.2.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Nov 11 2021 psimons@suse.com
- Update async to version 2.2.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Oct  7 2021 psimons@suse.com
- Update async to version 2.2.4.
  [#]# Changes in 2.2.4:
  - Support for GHC 9.2
* Fri Feb 19 2021 psimons@suse.com
- Update async to version 2.2.3.
  [#]# Changes in 2.2.3:
  - Documentation fixes
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update async to version 2.2.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Jun  7 2019 psimons@suse.com
- Update async to version 2.2.2.
  [#]# Changes in 2.2.2:
  - Builds with GHC 8.6.x
  - linkOnly and link2Only are now exported
  - wait now has the same behaviour with BlockedIndefinitelyOnSTM as waitCatch
  - Documentation fixes
* Fri Oct 19 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support ghc-8.6.1.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update async to version 2.2.1.
  - Add a Hashable instance for Async
  - Documentation updates
  - cancel now throws AsyncCancelled instead of ThreadKilled
  - link and link2 now wrap exceptions in ExceptionInLinkedThread when
  throwing to the linked thread. ExceptionInLinkedThread is a child
  of AsyncException in the exception hierarchy, so this maintains the
  invariant that exceptions thrown asynchronously should be
  AsyncExceptions.
  - link and link2 do not propagate AsyncCancelled, so it's now
  possible to cancel a linked thread without cancelling yourself.
  - Added linkOnly and link2Only to specify which exceptions should be
  propagated,if you want something other than the default behaviour
  of ignoring AsyncCancelled.
  - new utility function compareAsyncs for comparing Asyncs of
  different types.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 2.1.1.1 with cabal2obs.
* Tue Nov 22 2016 psimons@suse.com
- Update to version 2.1.1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.1.0 revision 0 with cabal2obs.
* Sun Jan 24 2016 mimi.vx@gmail.com
- update to 2.1.0
  * Bump base dependency to allow 4.10
  * Remove invalid Monad instance for Concurrently
  * Add Monoid and Semigroup instances for Concurrently
  * Add forConcurrently (flipped version of mapConcurrently)
  * Add STM version of all applicable IO functions: waitAnySTM, waitAnyCatchSTM,
    waitEitherSTM, waitEitherCatchSTM, waitEitherSTM_, and waitBothSTM.
* Mon Apr 13 2015 mimi.vx@gmail.com
- update to 2.0.2
  * Add a Monad instance for Concurrently * Bump base dependency to allow 4.9
  * Add workaround to waitCatch for #14
* Tue Sep  9 2014 peter.trommler@ohm-hochschule.de
- update to 2.0.1.5
  * update dependency for ghc 7.8
  * for Haskell Platform 2014.2.0.0
* Mon Sep  1 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file with cabal-rpm 0.8.6
  * require exact version of ghc-compiler
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 2.0.1.4 from upstream
  * fix in test suite
- version required for Haskell Platform 2013.2
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- more transparent packaging (fewer macros)
* Wed Jan  2 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Mon Oct  1 2012 peter.trommler@ohm-hochschule.de
- Initial package generated by cabal2spec
